@---------------------------------------------------------------------------@
@   SSREGS4 - this program uses daily expenditures. Days separated.         @
@   HOUSEHOLDS WITH AT LEAST 70 PERCENT OF INCOME FROM SS                   @
@                                                                           @
@   For simplicity, I have just modified Honore's DEMO.GSP program.         @
@   I use PANTOB.F1, which I have modified to use the SORTIND procedure     @
@   since GAUSS for DOS cannot ^^^^^^^ find it by itself.                   @
@                                                                           @
@---------------------------------------------------------------------------@

@---------------------------------------------------------------------------@
@   First, take care of some housekeeping.  Reference the necessary         @
@   libraries and include the necessary files.                              @
@---------------------------------------------------------------------------@

library optmum;                         @-----------------------------------@
#include optmum.ext;                    @   OPTMUM is used to optimize the  @
#include colors;                        @   objective function.  PANTOB     @
#include pantob.f1;                     @   contains the estimation         @
#include wrtpt;                         @   routines.  WRTPT and COLORS     @
                                        @   present PANTOB's output on the  @
                                        @   monitor.                        @
                                        @-----------------------------------@



format /mb1 /ld 6,4;

@ Make a vector of the X variables to be used @
xvarcols = {13 14 15 16 17 18
            19 20 21 22 23 24 25
            26 27 28 29 30 31 32 33 34 35
            36 37 38 39 40 41 42 43 44 45
            46 47 48 49 50 51 52
            53 54 55 56 57 58};

/* Dont forget - do not need d_min1 */
let varnames = hhid totalexp apparel foodtot2 foodhom2 foodawa2 fresh totaway pure
               alchaway stnondur stnondu2 survday2 survday3 survday4 survday5 survday6 survday7
               sweek2 swk2day2 swk2day3 swk2day4 swk2day5 swk2day6 swk2day7
               d_min14 d_min13 d_min12 d_min11 d_min10 d_min9 d_min8 d_min7 d_min6 d_min5 
               d_min4 d_min3 d_min2 d_0 d_plus1 d_plus2 d_plus3 d_plus4 d_plus5 d_plus6
               d_plus7 d_plus8 d_plus9 d_plus10 d_plus11 d_plus12 d_plus13
               sun tue wed thu fri sat; /* Names of variables */


                                        @-----------------------------------@
_amftol=0.00001;                        @   Set convergence tolerance for   @
                                        @   the downhill simplex method.    @
                                        @-----------------------------------@

                                        @-----------------------------------@
__output=2;                             @   __output is a global variable   @
                                        @   used by OPTMUM.  If __output=0  @
                                        @   none of the output of any of    @
                                        @   optimization routines is shown. @
                                        @-----------------------------------@


output file=d:\gauss\pantob\outfiles\gauss_figure4.out reset;


@ Total Expenditures @

print "Total expenditures began at " timestr(0) " on " datestr(0);

b0 = {-54.04467, -58.05253, -63.00884, -54.97645, -66.41849, -72.66205,
      -40.9968, 27.80799, 33.04413, 42.43063, 29.95276, 39.68189, 50.90188,
      -27.54535, -32.0208, -27.15874, -30.68891, -14.50894, -28.39305, -36.04829, 
      -25.974, -24.84942, -21.0964, -17.53075, -14.17876, 15.89414,
       20.618, -2.407356, 5.085479, -16.12134, -15.59358, -16.91677, -32.52316,
       -23.15519, -28.18432, -32.07307, -35.0855, -23.3551, -23.42065, -25.85188, 
       -5.60887, -7.330628, .2327588, 3.730941, -17.25675, -33.85955}; 

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("ssdailyd",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("ssdailyd",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(xnames~b0~b1~b2,0~1~1~1);


print "Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(xnames~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(xnames~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);



@ Strict Non-Durables @

b0 = {-10.9555, -12.3217, -12.70098, -12.82669, -13.66345, -14.01697, 
      -6.226627, 4.692334, 5.548592, 6.434724, 5.754698, 6.012381, 7.414898, 
      -1.173625, -.6849556, -1.176633, -.4652462, -1.348091, -1.264872, -1.393977, 
      -1.017268, -2.12624, -1.336785, -1.12049, -.9159231, -.709182, 
      1.373005, .7242606, -.0211101, -.2235354, -.69158, -.8516582, -.3469713, 
      -1.066828, -.9024789, -.8576471, -1.238865, -.9102271, -1.87745, -.5414735, 
      .4965666, 1.260647, 1.678775, 4.767519, 3.268469, -2.779675};


print "Strict non-durables began at " timestr(0) " on " datestr(0);

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("ssdailyd",11,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("ssdailyd",11,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Strict Non-Durables starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(xnames~b0~b1~b2,0~1~1~1);


print "Strict Non-Durables - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(xnames~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Strict Non-Durables - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(xnames~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Strict non-durables ended at " timestr(0) " on " datestr(0);



@ Food and Alcohol at Home @

b0 = {-7.24332, -8.07077, -8.170173, -8.259716, -8.907657, -8.84161, 
      -3.803576, 3.052159, 3.410445, 3.673325, 3.554017, 3.830723, 4.405337, 
      -.9154811, -.8288754, -1.238717, -.7059302, -1.280986, -1.084032, -1.069681, 
      -1.151014, -1.857972, -1.331249, -1.015483, -1.036617, -.7979714, 
      .5780653, .3629096, -.4336636, -.7450904, -.7348209, -.6310512, -.9032626, 
      -1.066207, -.7530519, -.7437294, -.9612978, -.9404844, -1.323162, -.715067, 
      .2164487, .519987, 1.019093, 2.667773, 1.835491, -2.428326};


print "Food and alcohol at home began at " timestr(0) " on " datestr(0);

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("ssdailyd",5,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("ssdailyd",5,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Food and Alcohol at Home starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(xnames~b0~b1~b2,0~1~1~1);


print "Food and Alcohol at Home - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(xnames~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Food and Alcohol at Home - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(xnames~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Food and alcohol at home ended at " timestr(0) " on " datestr(0);



@ Food and Alcohol Away @

b0 = {-.9916965, -1.197981, -1.153655, -1.309514, -1.302466, -1.568634, 
      -.5332611, .3898999, .4417208, .8186409, .4303651, .4362682, .6912294, 
      .1467323, .3463601, .2951048, .2849746, .1431687, -.007994, .2043396, 
      .4698358, -.1215037, .2454165, .0037977, .20218, .0865968, 
      .1491612, .1966047, .4337717, .1770393, .0793537, .1746896, .5837744, 
      .1889836, .2009677, .1954508, .0499631, .234301, .0042074, .3670714, 
      .3029224, .5140302, .2317644, 1.127223, 1.234075, .975229};

print "Food and alcohol away from home began at " timestr(0) " on " datestr(0);

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("ssdailyd",6,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("ssdailyd",6,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Food and Alcohol Away starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(xnames~b0~b1~b2,0~1~1~1);


print "Food and Alcohol Away - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(xnames~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Food and Alcohol Away - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(xnames~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Food and alcohol away from home ended at " timestr(0) " on " datestr(0);



@ Total Away @

b0 = {-1.048447, -1.287022, -1.283995, -1.493791, -1.409317, -1.571482, 
      -.6675594, .3828445, .4794235, .9915475, .5946415, .5448055, .6717941, 
      -.0167629, .2052871, .2422227, .6936646, .0877244, -.0618631, .077125, 
      .3990255, -.0809453, .1478725, -.1206823, .1839422, .3316182, 
      .0376913, .0917147, .3171162, .0718181, .0525845, .1112427, .4823847, 
      .0553584, .2129177, .0453336, -.1109724, .2508238, .0097417, .2753393, 
      .14192, .4469794, .1745344, 1.108737, 1.177311, .8319012};

print "Total away began at " timestr(0) " on " datestr(0);

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("ssdailyd",8,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("ssdailyd",8,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Total Away starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(xnames~b0~b1~b2,0~1~1~1);


print "Total Away - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(xnames~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Total Away - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(xnames~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total away ended at " timestr(0) " on " datestr(0);



@ Fresh @

b0 = {-1.312964, -1.405635, -1.442366, -1.44803, -1.587011, -1.565833, 
      -.5918048, .4497147, .5026597, .5651531, .5260591, .5829416, .6860645, 
      -.113356, -.0418698, -.1299757, -.0669548, -.1798234, -.0888597, -.0964735, 
      -.2101946, -.1902476, -.1372996, -.1862733, -.1680032, -.0966958, 
      .0357813, .0614742, -.0662785, -.0235028, -.0679964, -.1594814, -.0610525, 
      -.1621366, -.0671883, -.0942486, -.1205108, -.1235811, -.1558421, -.1488481, 
      -.0144774, .0502247, .1016069, .4104605, .2244768, -.4642369};


print "Fresh foods began at " timestr(0) " on " datestr(0);

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("ssdailyd",7,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("ssdailyd",7,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Fresh starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(xnames~b0~b1~b2,0~1~1~1);


print "Fresh - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(xnames~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Fresh - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(xnames~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Fresh foods ended at " timestr(0) " on " datestr(0);



@ Pure @

b0 = {-2.361411, -2.692656, -2.726362, -2.941821, -2.996328, -3.137314, 
      -1.259364, .8325592, .9820833, 1.556701, 1.120701, 1.127747, 1.357859, 
      -.130119, .1634173, .112247, .6267097, -.0920989, -.1507228, -.0193485, 
      .1888309, -.2711929, .010573, -.3069556, .015939, .2349224, 
      .0734726, .1531889, .2508376, .0483154, -.0154119, -.0482387, .4213322, 
      -.1067783, .1457294, -.048915, -.2314832, .1272427, -.1461005, .1264912, 
      .1274426, .4972041, .2761413, 1.519198, 1.401788, .3676643};



print "Pure began at " timestr(0) " on " datestr(0);

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("ssdailyd",9,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("ssdailyd",9,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Pure starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(xnames~b0~b1~b2,0~1~1~1);


print "Pure - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(xnames~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Pure - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(xnames~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Pure ended at " timestr(0) " on " datestr(0);


@ Jump out of Gauss @
system;

@ End the program @
end;
