@---------------------------------------------------------------------------@
@   SSREGS3 - this program uses daily expenditures. Pool Weeks.             @
@   HOUSEHOLDS WITH AT LEAST 70 PERCENT OF INCOME FROM SS                   @
@                                                                           @
@   For simplicity, I have just modified Honore's DEMO.GSP program.         @
@   I use PANTOB.F1, which I have modified to use the SORTIND procedure     @
@   since GAUSS for DOS cannot ^^^^^^^ find it by itself.                   @
@                                                                           @
@---------------------------------------------------------------------------@

@---------------------------------------------------------------------------@
@   First, take care of some housekeeping.  Reference the necessary         @
@   libraries and include the necessary files.                              @
@---------------------------------------------------------------------------@

library optmum;                         @-----------------------------------@
#include optmum.ext;                    @   OPTMUM is used to optimize the  @
#include colors;                        @   objective function.  PANTOB     @
#include pantob.f1;                     @   contains the estimation         @
#include wrtpt;                         @   routines.  WRTPT and COLORS     @
                                        @   present PANTOB's output on the  @
                                        @   monitor.                        @
                                        @-----------------------------------@



format /mb1 /ld 6,4;

@ Make a vector of the X variables to be used @
xvarcols = {13 14 15 16 17 18
            19 20 21 22 23 24 25
            26 27 28 29 30 31 32 33 34};

let varnames = hhid totalexp apparel foodtot2 foodhom2 foodawa2 fresh totaway pure
               alchaway stnondur stnondu2 survday2 survday3 survday4 survday5 survday6 survday7
               sweek2 swk2day2 swk2day3 swk2day4 swk2day5 swk2day6 swk2day7
               d_week1 d_week3 d_week4 sun tue wed thu fri sat; /* Names of variables */


                                        @-----------------------------------@
_amftol=0.00001;                        @   Set convergence tolerance for   @
                                        @   the downhill simplex method.    @
                                        @-----------------------------------@

                                        @-----------------------------------@
__output=2;                             @   __output is a global variable   @
                                        @   used by OPTMUM.  If __output=0  @
                                        @   none of the output of any of    @
                                        @   optimization routines is shown. @
                                        @-----------------------------------@


output file=d:\gauss\pantob\outfiles\gauss_table3.out reset;


@ Total Expenditures @

print "Total expenditures began at " timestr(0) " on " datestr(0);

b0 = {-53.96176, -57.99016, -62.97149, -54.72459, -66.2102, -72.38172,
      -40.71546, 27.67035, 32.80254, 42.20026, 29.40176, 39.16969, 50.2521,
      -13.29302, 4.634743, -11.70096, -2.607515, -3.742359, -.3834142, 6.5682, -16.51395, -32.64766};

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("ssdailyc",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("ssdailyc",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(xnames~b0~b1~b2,0~1~1~1);


print "Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(xnames~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(xnames~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);



@ Strict Non-Durables @

b0 = {-10.95825, -12.32727,  -12.70027, -12.82496,  -13.65543,  -14.01172,
      -6.212166, 4.690052, 5.541198, 6.425, 5.728639, 5.98065,  7.38627,
     .024841, 1.038014, .0717525, .4465071, 1.1779, 1.842056, 4.899308, 3.22185, -2.843901};


print "Strict non-durables began at " timestr(0) " on " datestr(0);

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("ssdailyc",11,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("ssdailyc",11,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Strict Non-Durables starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(xnames~b0~b1~b2,0~1~1~1);


print "Strict Non-Durables - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(xnames~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Strict Non-Durables - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(xnames~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Strict non-durables ended at " timestr(0) " on " datestr(0);



@ Food and Alcohol at Home @

b0 = {-7.244556, -8.074728, -8.171047, -8.256301, -8.900912, -8.83323,
      -3.792475, 3.049786, 3.408319, 3.669148, 3.540064, 3.810385, 4.384337,
      .0764115, .6601662, .1640484, .1950267, .5292326, 1.127716, 2.743067, 1.824303, -2.480338};

print "Food and alcohol at home began at " timestr(0) " on " datestr(0);

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("ssdailyc",5,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("ssdailyc",5,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Food and Alcohol at Home starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(xnames~b0~b1~b2,0~1~1~1);


print "Food and Alcohol at Home - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(xnames~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Food and Alcohol at Home - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(xnames~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Food and alcohol at home ended at " timestr(0) " on " datestr(0);



@ Food and Alcohol Away @

b0 = {-.9892967, -1.194283, -1.148423, -1.307775, -1.297835, -1.56775,
      -.5281797, .3872693, .4352739, .8153742, .4220537, .430064, .6880703,
      .0484988, .1317067, .0267239, .3154942, .516791, .3123796, 1.168285, 1.233105, 1.025129};


print "Food and alcohol away from home began at " timestr(0) " on " datestr(0);

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("ssdailyc",6,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("ssdailyc",6,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Food and Alcohol Away starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(xnames~b0~b1~b2,0~1~1~1);


print "Food and Alcohol Away - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(xnames~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Food and Alcohol Away - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(xnames~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Food and alcohol away from home ended at " timestr(0) " on " datestr(0);



@ Total Away @

b0 = {-1.047601,  -1.282934, -1.278033, -1.490345, -1.404287, -1.568647, 
      -.6619498, .3822691, .4747605, .9876754, .5866842, .5386149, .667412, 
      .024976, .0415909, -.0464942, .1452592, .4430003, .2106039, 1.103316, 1.169193, .8561907};

print "Total away began at " timestr(0) " on " datestr(0);

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("ssdailyc",8,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("ssdailyc",8,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Total Away starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(xnames~b0~b1~b2,0~1~1~1);


print "Total Away - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(xnames~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Total Away - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(xnames~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total away ended at " timestr(0) " on " datestr(0);



@ Fresh @

b0 = {-1.314669, -1.407287, -1.443553, -1.449247, -1.587434, -1.565887,
      -.5914534, .4511269, .5042214, .5654692, .5260133, .5820345, .6850618,
      .0492656, .0972644, .0229742, -.019021, .0538507, .1226094, .4154246, .2408911, -.4645531};


print "Fresh foods began at " timestr(0) " on " datestr(0);

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("ssdailyc",7,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("ssdailyc",7,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Fresh starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(xnames~b0~b1~b2,0~1~1~1);


print "Fresh - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(xnames~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Fresh - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(xnames~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Fresh foods ended at " timestr(0) " on " datestr(0);



@ Pure @

b0 = {-2.36227, -2.690221, -2.721586, -2.939592, -2.991721, -3.134534,
      -1.253403, .8333961, .9789819, 1.553145, 1.112698, 1.120649, 1.352474,
      .1262382, .4968509, .3332133, 1.51874, 1.410084, .3916376, .0742416, .1388553, -.0235201};


print "Pure began at " timestr(0) " on " datestr(0);

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("ssdailyc",9,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("ssdailyc",9,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Pure starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(xnames~b0~b1~b2,0~1~1~1);


print "Pure - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(xnames~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Pure - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(xnames~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Pure ended at " timestr(0) " on " datestr(0);



@ Jump out of Gauss @
system;

@ End the program @
end;
