*** Create an ASCII DATA FILE FOR GAUSS ***;
*** Only households that receive SS ***;
*** Also, limit to households from 1986-1996 ***;
*** AND where either the reference person or spouse receives SS ***;

options ls=76 ps=56 errors=2 compress=yes obs=max;

*** Directories ***;
%let libdir=~/CEX/Diary/Perms;
%let asciidir=~/CEX/Diary/Perms; * Output *;

libname perm "&libdir.";


*** Read in the data and merge it together ***;

data all8696;
  set perm.daily86 perm.daily87 perm.daily88 perm.daily89 perm.daily90 
      perm.daily91 perm.daily92 perm.daily93 perm.daily94 perm.daily95
      perm.daily96;
run;


*** Keep only households that get Social Security ***;

data all8696;
  set all8696;

  if (fss_rrx>0);
  if ((ss_rel1=1) or (ss_rel1=2) or (ss_rel2=2));

  ** Complete income reporter **;
  if respstat=1;

  *** Cannot use January observations ***;
  if (jandif3a ne .) then delete;
  ** Cannot use if falls outside 14 days before or 13 days after the third **;
  if (anndif3a ne .);

  ** Household identifier **;
  hhid = cuid*100 + year;

run;


*** Generate expenditure categories ***;
data all8696;
  set all8696;

  stnondur = foodtot2 + smoksupp + persprod + persserv + pubtran + gas;
  pure = fresh + totaway;
run;

  
*** For those households which have days that correspond to two checks, ***;
*** have to deflate the first weeks expenditures ***;
*** Days in first part of overlap will tend to have higher values ***;
*** Thus, need to deflate days from first part of overlap ***;
data junk(keep=hhid weeki diarydow fss_rrx anndif3a);
  set all8696;

  if (((weeki=1) and (diarydow=1)) or ((weeki=2) and (diarydow=7)));
run;

proc sort data=junk;
  by hhid weeki;
run;


data junk(keep=hhid deflate firstday lastday);
  set junk;

  by hhid weeki;

  retain firstday;

  if first.hhid then do;
    if ((weeki=1) and (anndif3a>0)) then firstday = fss_rrx;
    else firstday = 0;
  end;
  if last.hhid then do;
    if ((weeki=2) and (anndif3a<0)) then lastday = fss_rrx;
    else lastday = 0;
    if ((firstday>0) and (lastday>0)) then deflate = lastday/firstday;
    else deflate=1;
    output;
  end;
run;

proc sort data=all8696;
  by hhid;
run;

proc sort data=junk;
  by hhid;
run;

data all8696;
  merge all8696(in=inall) junk(in=injunk);
  by hhid;
  if inall;
  if (deflate=.) then deflate=1;
run;

data junk;
run;


data all8696;
  set all8696;

  array expvars {*} totalexp apparel foodtot2 foodhom2 foodawa2
                    fresh totaway pure alchaway stnondur stnondu2;

  do i=1 to dim(expvars);
    expvars(i) = expvars(i)*deflate;
  end;
run;



*** Create some variables for regressions ***;
*** Have to move the day by day indicators ***;
*** Use -14 to 13 here for daily expenditures ***;
*** Used -13 to 14 for weekly change where day was 1st of 2nd diary week **;
data all8696(drop=i tempi tempyear tempm14);
  set all8696;

  length year86-year96 jan feb mar apr may jun jul aug sep oct nov dec
         d_min14 d_min13 d_min12 d_min11 d_min10 d_min9 d_min8 d_min7 d_min6
         d_min5 d_min4 d_min3 d_min2 d_min1 d_0 d_plus1 d_plus2
         d_plus3 d_plus4 d_plus5 d_plus6 d_plus7 d_plus8 d_plus9
         d_plus10 d_plus11 d_plus12 d_plus13
         d_week1-d_week4 survday1-survday7 sun mon tue wed thu fri sat 3;


  array yeararr {*} year86-year96;

  array monthind {*} jan feb mar apr may jun jul aug sep oct nov dec;


  array monthdif {*} jandif3a febdif3a mardif3a aprdif3a maydif3a jundif3a
                     juldif3a augdif3a sepdif3a octdif3a novdif3a decdif3a;

  array dinds {*} d_min14 d_min13 d_min12 d_min11 d_min10 d_min9 d_min8 d_min7
                  d_min6 d_min5 d_min4 d_min3 d_min2 d_min1 d_0 d_plus1
                  d_plus2 d_plus3 d_plus4 d_plus5 d_plus6 d_plus7 d_plus8
                  d_plus9 d_plus10 d_plus11 d_plus12 d_plus13;

  array survdind {*} survday1-survday7;

  array dowind {*} sun mon tue wed thu fri sat;

  ** Create year indicators **;
  do i=1 to dim(yeararr);
    tempi=i;
    tempyear=tempi+85;
    if (tempyear=year) then yeararr(tempi)=1;
    else yeararr(i)=0;
  end;

  ** Create month indicators **;
  do i=1 to dim(monthind);
    if (monthdif(i) ne .) then monthind(i)=1;
    else monthind(i)=0;
  end;

  ** Create day before or after indicators **;
  do i=1 to dim(dinds);
    tempi=i;
    tempm14=tempi - 15; ** Where in relation to anndif3a **;
    if (tempm14=anndif3a) then dinds(tempi)=1;
    else dinds(tempi)=0;
  end;

  ** Create weekly indicators **;
  ** Based on weeks that include the ADJUSTED THIRD **;
  ** Two weeks before the third and two weeks after **;
  d_week1 = sum(d_min14,d_min13,d_min12,d_min11,d_min10,d_min9,d_min8);
  d_week2 = sum(d_min7,d_min6,d_min5,d_min4,d_min3,d_min2,d_min1);
  d_week3 = sum(d_0,d_plus1,d_plus2,d_plus3,d_plus4,d_plus5,d_plus6);
  d_week4 = sum(d_plus7,d_plus8,d_plus9,d_plus10,d_plus11,d_plus12,d_plus13);

  ** Create diaryday indicators - which of the seven days it refers to **;
  do i=1 to dim(survdind);
    tempi=i;
    if (tempi=diaryday) then survdind(i)=1;
    else survdind(i)=0;
  end;

  ** Create diary day of week (diarydow) indicators **;
  do i=1 to dim(dowind);
    tempi=i;
    if (tempi=diarydow) then dowind(i)=1;
    else dowind(i)=0;
  end;

  *** Round off all of the expenditure data for conversion to GAUSS ***;
  totalexp = round(totalexp,.01);
  apparel  = round(apparel ,.01);
  foodtot2 = round(foodtot2,.01);
  foodhom2 = round(foodhom2,.01);
  foodawa2 = round(foodawa2,.01);
  fresh    = round(fresh   ,.01);
  totaway  = round(totaway ,.01);
  pure     = round(pure    ,.01);
  alchaway = round(alchaway,.01);
  stnondur = round(stnondur,.01);
  stnondu2 = round(stnondu2,.01);


  ** Generate survey day interacted with second diary week **;
  if (weeki=2) then sweek2 = 1;
  else sweek2 = 0;
  swk2day1 = survday1*sweek2;
  swk2day2 = survday2*sweek2;
  swk2day3 = survday3*sweek2;
  swk2day4 = survday4*sweek2;
  swk2day5 = survday5*sweek2;
  swk2day6 = survday6*sweek2;
  swk2day7 = survday7*sweek2;

  ** Generate ssratio variables **;
  ssratio = fss_rrx/fincbefx;

run;



*** Write out the ascii files ***;

*** Write out ssdaily1.dat ***;
data _NULL_;
  set all8696;
  file "&asciidir./ssdaily1.asc";
  put hhid totalexp apparel foodtot2 foodhom2 foodawa2 fresh totaway pure
      alchaway stnondur stnondu2 survday2-survday7 sweek2 swk2day2-swk2day7
      d_min14 d_min13 d_min12 d_min11 d_min10 d_min9 d_min8 d_min7 d_min6
      d_min5 d_min4 d_min3 d_min2 d_min1 d_0 d_plus1 d_plus2
      d_plus3 d_plus4 d_plus5 d_plus6 d_plus7 d_plus8 d_plus9
      d_plus10 d_plus11 d_plus12 d_plus13
      d_week1 d_week3 d_week4 tue wed thu fri sat sun;
run;


proc means data=all8696;
  var _NUMERIC_;
  title 'All observations';
run;




*** Now get CUs with at least 70% of income from SS ***;
options obs=max;

data junk;
  set all8696;
  if ssratio>=.70;
run;

*** Write out ssdaily2.dat ***;
data _NULL_;
  set junk;
  file "&asciidir./ssdaily2.asc";
  put hhid totalexp apparel foodtot2 foodhom2 foodawa2 fresh totaway pure
      alchaway stnondur stnondu2 survday2-survday7 sweek2 swk2day2-swk2day7
      d_min14 d_min13 d_min12 d_min11 d_min10 d_min9 d_min8 d_min7 d_min6
      d_min5 d_min4 d_min3 d_min2 d_min1 d_0 d_plus1 d_plus2
      d_plus3 d_plus4 d_plus5 d_plus6 d_plus7 d_plus8 d_plus9
      d_plus10 d_plus11 d_plus12 d_plus13
      d_week1 d_week3 d_week4 tue wed thu fri sat sun;
run;


proc means data=junk;
  var _NUMERIC_;
  title 'CUs with ssratio>=.70';
run;
