*** Create a permanent dataset from the individual years of the daily CEX ***;
*** diary data using 1986-1996 CEX for Third of Tha Month paper ***;

*** To conserve space, limit to households that recieve some SS INCOME ***;
options ls=76 ps=56 errors=2 compress=yes obs=max;

%include "cexdirs.in"/source2;


*** Read in the data and merge it together ***;

data all8696;
  set outperm.daily86 outperm.daily87 outperm.daily88 outperm.daily89
      outperm.daily90 outperm.daily91 outperm.daily92 outperm.daily93
      outperm.daily94 outperm.daily95 outperm.daily96
      ;
run;


*** Keep only households that report receiving Social Security on FMLY file **;

data all8696;
  set all8696;

  if (fss_rrx>0);
run;

  
*** Create some variables for regressions ***;
*** Have to move the day by day indicators ***;
*** Use -14 to 13 here for daily expenditures ***;
*** Used -13 to 14 for weekly change where day was 1st of 2nd diary week **;
data all8696(drop=i tempi tempyear tempm14);
  set all8696;

  length year86-year96 jan feb mar apr may jun jul aug sep oct nov dec
         d_min14 d_min13 d_min12 d_min11 d_min10 d_min9 d_min8 d_min7 d_min6
         d_min5 d_min4 d_min3 d_min2 d_min1 d_0 d_plus1 d_plus2
         d_plus3 d_plus4 d_plus5 d_plus6 d_plus7 d_plus8 d_plus9
         d_plus10 d_plus11 d_plus12 d_plus13
         d_week1-d_week4 survday1-survday7 sun mon tue wed thu fri sat 3;


  array yeararr {*} year86-year96;

  array monthind {*} jan feb mar apr may jun jul aug sep oct nov dec;

  array monthdif {*} jandif3a febdif3a mardif3a aprdif3a maydif3a jundif3a
                     juldif3a augdif3a sepdif3a octdif3a novdif3a decdif3a;

  array dinds {*} d_min14 d_min13 d_min12 d_min11 d_min10 d_min9 d_min8 d_min7
                  d_min6 d_min5 d_min4 d_min3 d_min2 d_min1 d_0 d_plus1
                  d_plus2 d_plus3 d_plus4 d_plus5 d_plus6 d_plus7 d_plus8
                  d_plus9 d_plus10 d_plus11 d_plus12 d_plus13;

  array survdind {*} survday1-survday7;

  array dowind {*} sun mon tue wed thu fri sat;

  ** Create year indicators **;
  do i=1 to dim(yeararr);
    tempi=i;
    tempyear=tempi+85;
    if (tempyear=year) then yeararr(tempi)=1;
    else yeararr(i)=0;
  end;

  ** Create month indicators **;
  do i=1 to dim(monthind);
    if (monthdif(i) ne .) then monthind(i)=1;
    else monthind(i)=0;
  end;

  ** Create day before or after indicators **;
  do i=1 to dim(dinds);
    tempi=i;
    tempm14=tempi - 15; ** Where in relation to anndif3a **;
    if (tempm14=anndif3a) then dinds(tempi)=1;
    else dinds(tempi)=0;
  end;

  ** Create weekly indicators **;
  ** Based on weeks that include the ADJUSTED THIRD **;
  ** Two weeks before the third and two weeks after **;
  d_week1 = sum(d_min14,d_min13,d_min12,d_min11,d_min10,d_min9,d_min8);
  d_week2 = sum(d_min7,d_min6,d_min5,d_min4,d_min3,d_min2,d_min1);
  d_week3 = sum(d_0,d_plus1,d_plus2,d_plus3,d_plus4,d_plus5,d_plus6);
  d_week4 = sum(d_plus7,d_plus8,d_plus9,d_plus10,d_plus11,d_plus12,d_plus13);

  ** Create diaryday indicators - which of the seven days it refers to **;
  do i=1 to dim(survdind);
    tempi=i;
    if (tempi=diaryday) then survdind(i)=1;
    else survdind(i)=0;
  end;

  ** Create diary day of week (diarydow) indicators **;
  do i=1 to dim(dowind);
    tempi=i;
    if (tempi=diarydow) then dowind(i)=1;
    else dowind(i)=0;
  end;
run;


data outperm.ssdaily8696;
  set all8696;
run;

proc means data=outperm.ssdaily8696;
  var _NUMERIC_;
run;
