@---------------------------------------------------------------------------@
@   BATOT70 - this program uses daily expenditures. Pool Weeks.             @
@   BOOTSTRAPPING OF TOTAL EXPENDITURES FOR HOUSEHOLDS WITH 70% FROM SS     @
@   HOUSEHOLDS WITH AT LEAST 70 PERCENT OF INCOME FROM SS                   @
@   THE SECOND CHARACTER "A" IN THE TITLE REFERS TO                         @
@   THE 70 OR MORE GROUP AND USING WEEKLY INDICATORS IN THE REGRESSIONS     @
@                                                                           @
@   TOTAL EXPENDITURES                                                      @
@                                                                           @
@   For simplicity, I have just modified Honore's DEMO.GSP program.         @
@   I use PANTOB.F1, which I have modified to use the SORTIND procedure     @
@   since GAUSS for DOS cannot ^^^^^^^ find it by itself.                   @
@                                                                           @
@---------------------------------------------------------------------------@

@---------------------------------------------------------------------------@
@   First, take care of some housekeeping.  Reference the necessary         @
@   libraries and include the necessary files.                              @
@---------------------------------------------------------------------------@

library optmum;                         @-----------------------------------@
#include optmum.ext;                    @   OPTMUM is used to optimize the  @
#include colors;                        @   objective function.  PANTOB     @
#include pantob.f1;                     @   contains the estimation         @
#include wrtpt;                         @   routines.  WRTPT and COLORS     @
                                        @   present PANTOB's output on the  @
                                        @   monitor.                        @
                                        @-----------------------------------@



format /mb1 /ld 6,4;

@ Make a vector of the X variables to be used @
xvarcols = {13 14 15 16 17 18
            19 20 21 22 23 24 25
            26 27 28 29 30 31 32 33 34};

let varnames = hhid totalexp apparel foodtot2 foodhom2 foodawa2 fresh totaway pure
               alchaway stnondur stnondu2 survday2 survday3 survday4 survday5 survday6 survday7
               sweek2 swk2day2 swk2day3 swk2day4 swk2day5 swk2day6 swk2day7
               d_week1 d_week3 d_week4 sun tue wed thu fri sat; /* Names of variables */

let regvars =  survday2 survday3 survday4 survday5 survday6 survday7
               sweek2 swk2day2 swk2day3 swk2day4 swk2day5 swk2day6 swk2day7
               d_week1 d_week3 d_week4 tue wed thu fri sat sun; /* Name of vars in regs */
@ NOTE: NEED TO USE REGVARS BECAUSE THE STAT TRANSFER PROGRAM @
@ DOES NOT KEEP THE VARIABLE NAMES @
@ MAYBE FIX LATER BY USING STCMD RATHER OUTPUTST IN MAKEBOOT PROGRAMS @

@ Set initial values for total expenditures (from OLS) @
b0 = {-53.96176, -57.99016, -62.97149, -54.72459, -66.2102, -72.38172,
      -40.71546, 27.67035, 32.80254, 42.20026, 29.40176, 39.16969, 50.2521,
      -13.29302, 4.634743, -11.70096, -2.607515, -3.742359, -.3834142, 6.5682, -16.51395, -32.64766};

@ Initialize the counter for the repitition number @
repcount = 0;

                                        @-----------------------------------@
_amftol=0.00001;                        @   Set convergence tolerance for   @
                                        @   the downhill simplex method.    @
                                        @-----------------------------------@

                                        @-----------------------------------@
__output=2;                             @   __output is a global variable   @
                                        @   used by OPTMUM.  If __output=0  @
                                        @   none of the output of any of    @
                                        @   optimization routines is shown. @
                                        @-----------------------------------@


output file=d:\gauss\pantob\bootstr\batot70.out reset;


@ Repetition 1 Begins Here @

@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_1",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_1",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_1";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot1 = betaandp, vatot1 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);


@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_2",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_2",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_2";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot2 = betaandp, vatot2 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_3",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_3",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_3";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot3 = betaandp, vatot3 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_4",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_4",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_4";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot4 = betaandp, vatot4 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_5",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_5",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_5";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot5 = betaandp, vatot5 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_6",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_6",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_6";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot6 = betaandp, vatot6 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_7",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_7",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_7";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot7 = betaandp, vatot7 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_8",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_8",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_8";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot8 = betaandp, vatot8 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_9",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_9",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_9";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot9 = betaandp, vatot9 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Repetition 10 Begins Here @

@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_10",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_10",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_10";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot10 = betaandp, vatot10 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_11",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_11",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_11";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot11 = betaandp, vatot11 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);


@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_12",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_12",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_12";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot12 = betaandp, vatot12 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_13",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_13",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_13";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot13 = betaandp, vatot13 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_14",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_14",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_14";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot14 = betaandp, vatot14 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_15",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_15",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_15";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot15 = betaandp, vatot15 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_16",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_16",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_16";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot16 = betaandp, vatot16 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_17",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_17",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_17";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot17 = betaandp, vatot17 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_18",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_18",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_18";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot18 = betaandp, vatot18 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_19",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_19",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_19";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot19 = betaandp, vatot19 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Repetition 20 Begins Here @

@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_20",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_20",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_20";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot20 = betaandp, vatot20 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_21",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_21",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_21";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot21 = betaandp, vatot21 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);


@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_22",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_22",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_22";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot22 = betaandp, vatot22 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_23",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_23",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_23";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot23 = betaandp, vatot23 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_24",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_24",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_24";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot24 = betaandp, vatot24 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_25",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_25",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_25";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot25 = betaandp, vatot25 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_26",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_26",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_26";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot26 = betaandp, vatot26 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_27",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_27",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_27";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot27 = betaandp, vatot27 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_28",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_28",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_28";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot28 = betaandp, vatot28 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_29",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_29",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_29";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot29 = betaandp, vatot29 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Repetition 30 Begins Here @

@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_30",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_30",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_30";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot30 = betaandp, vatot30 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_31",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_31",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_31";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot31 = betaandp, vatot31 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);


@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_32",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_32",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_32";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot32 = betaandp, vatot32 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_33",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_33",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_33";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot33 = betaandp, vatot33 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_34",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_34",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_34";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot34 = betaandp, vatot34 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_35",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_35",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_35";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot35 = betaandp, vatot35 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_36",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_36",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_36";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot36 = betaandp, vatot36 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_37",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_37",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_37";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot37 = betaandp, vatot37 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_38",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_38",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_38";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot38 = betaandp, vatot38 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_39",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_39",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_39";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot39 = betaandp, vatot39 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Repetition 40 Begins Here @

@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_40",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_40",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_40";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot40 = betaandp, vatot40 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_41",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_41",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_41";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot41 = betaandp, vatot41 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);


@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_42",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_42",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_42";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot42 = betaandp, vatot42 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_43",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_43",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_43";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot43 = betaandp, vatot43 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_44",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_44",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_44";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot44 = betaandp, vatot44 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_45",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_45",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_45";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot45 = betaandp, vatot45 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_46",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_46",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_46";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot46 = betaandp, vatot46 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_47",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_47",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_47";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot47 = betaandp, vatot47 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_48",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_48",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_48";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot48 = betaandp, vatot48 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_49",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_49",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_49";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot49 = betaandp, vatot49 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Repetition 50 Begins Here @

@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_50",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_50",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_50";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot50 = betaandp, vatot50 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_51",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_51",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_51";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot51 = betaandp, vatot51 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);


@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_52",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_52",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_52";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot52 = betaandp, vatot52 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_53",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_53",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_53";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot53 = betaandp, vatot53 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_54",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_54",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_54";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot54 = betaandp, vatot54 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_55",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_55",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_55";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot55 = betaandp, vatot55 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_56",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_56",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_56";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot56 = betaandp, vatot56 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_57",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_57",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_57";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot57 = betaandp, vatot57 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_58",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_58",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_58";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot58 = betaandp, vatot58 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_59",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_59",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_59";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot59 = betaandp, vatot59 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Repetition 60 Begins Here @

@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_60",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_60",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_60";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot60 = betaandp, vatot60 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_61",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_61",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_61";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot61 = betaandp, vatot61 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);


@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_62",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_62",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_62";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot62 = betaandp, vatot62 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_63",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_63",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_63";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot63 = betaandp, vatot63 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_64",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_64",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_64";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot64 = betaandp, vatot64 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_65",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_65",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_65";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot65 = betaandp, vatot65 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_66",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_66",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_66";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot66 = betaandp, vatot66 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_67",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_67",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_67";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot67 = betaandp, vatot67 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_68",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_68",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_68";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot68 = betaandp, vatot68 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_69",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_69",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_69";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot69 = betaandp, vatot69 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Repetition 70 Begins Here @

@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_70",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_70",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_70";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot70 = betaandp, vatot70 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_71",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_71",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_71";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot71 = betaandp, vatot71 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);


@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_72",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_72",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_72";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot72 = betaandp, vatot72 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_73",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_73",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_73";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot73 = betaandp, vatot73 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_74",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_74",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_74";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot74 = betaandp, vatot74 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_75",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_75",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_75";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot75 = betaandp, vatot75 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_76",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_76",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_76";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot76 = betaandp, vatot76 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_77",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_77",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_77";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot77 = betaandp, vatot77 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_78",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_78",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_78";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot78 = betaandp, vatot78 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_79",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_79",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_79";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot79 = betaandp, vatot79 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Repetition 80 Begins Here @

@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_80",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_80",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_80";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot80 = betaandp, vatot80 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_81",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_81",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_81";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot81 = betaandp, vatot81 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);


@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_82",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_82",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_82";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot82 = betaandp, vatot82 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_83",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_83",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_83";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot83 = betaandp, vatot83 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_84",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_84",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_84";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot84 = betaandp, vatot84 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_85",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_85",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_85";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot85 = betaandp, vatot85 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_86",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_86",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_86";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot86 = betaandp, vatot86 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_87",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_87",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_87";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot87 = betaandp, vatot87 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_88",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_88",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_88";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot88 = betaandp, vatot88 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_89",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_89",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_89";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot89 = betaandp, vatot89 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Repetition 90 Begins Here @

@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_90",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_90",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_90";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot90 = betaandp, vatot90 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_91",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_91",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_91";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot91 = betaandp, vatot91 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);


@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_92",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_92",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_92";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot92 = betaandp, vatot92 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_93",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_93",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_93";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot93 = betaandp, vatot93 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_94",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_94",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_94";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot94 = betaandp, vatot94 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_95",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_95",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_95";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot95 = betaandp, vatot95 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_96",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_96",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_96";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot96 = betaandp, vatot96 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_97",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_97",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_97";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot97 = betaandp, vatot97 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_98",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_98",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_98";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot98 = betaandp, vatot98 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_99",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_99",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_99";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot99 = betaandp, vatot99 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);




@ Repetition 100 Begins Here @

@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_100",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_100",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_100";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot100 = betaandp, vatot100 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);


@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_101",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_101",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_101";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot101 = betaandp, vatot101 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);


@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_102",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_102",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_102";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot102 = betaandp, vatot102 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_103",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_103",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_103";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot103 = betaandp, vatot103 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_104",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_104",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_104";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot104 = betaandp, vatot104 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_105",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_105",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_105";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot105 = betaandp, vatot105 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_106",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_106",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_106";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot106 = betaandp, vatot106 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_107",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_107",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_107";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot107 = betaandp, vatot107 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_108",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_108",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_108";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot108 = betaandp, vatot108 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_109",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_109",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_109";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot109 = betaandp, vatot109 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Repetition 110 Begins Here @

@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_110",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_110",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_110";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot110 = betaandp, vatot110 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_111",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_111",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_111";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot111 = betaandp, vatot111 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);


@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_112",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_112",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_112";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot112 = betaandp, vatot112 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_113",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_113",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_113";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot113 = betaandp, vatot113 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_114",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_114",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_114";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot114 = betaandp, vatot114 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_115",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_115",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_115";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot115 = betaandp, vatot115 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_116",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_116",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_116";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot116 = betaandp, vatot116 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_117",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_117",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_117";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot117 = betaandp, vatot117 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_118",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_118",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_118";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot118 = betaandp, vatot118 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_119",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_119",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_119";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot119 = betaandp, vatot119 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Repetition 120 Begins Here @

@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_120",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_120",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_120";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot120 = betaandp, vatot120 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_121",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_121",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_121";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot121 = betaandp, vatot121 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);


@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_122",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_122",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_122";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot122 = betaandp, vatot122 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_123",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_123",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_123";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot123 = betaandp, vatot123 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_124",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_124",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_124";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot124 = betaandp, vatot124 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_125",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_125",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_125";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot125 = betaandp, vatot125 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_126",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_126",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_126";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot126 = betaandp, vatot126 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_127",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_127",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_127";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot127 = betaandp, vatot127 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_128",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_128",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_128";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot128 = betaandp, vatot128 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_129",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_129",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_129";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot129 = betaandp, vatot129 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Repetition 130 Begins Here @

@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_130",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_130",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_130";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot130 = betaandp, vatot130 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_131",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_131",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_131";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot131 = betaandp, vatot131 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);


@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_132",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_132",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_132";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot132 = betaandp, vatot132 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_133",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_133",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_133";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot133 = betaandp, vatot133 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_134",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_134",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_134";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot134 = betaandp, vatot134 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_135",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_135",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_135";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot135 = betaandp, vatot135 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_136",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_136",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_136";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot136 = betaandp, vatot136 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_137",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_137",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_137";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot137 = betaandp, vatot137 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_138",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_138",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_138";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot138 = betaandp, vatot138 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_139",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_139",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_139";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot139 = betaandp, vatot139 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Repetition 140 Begins Here @

@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_140",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_140",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_140";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot140 = betaandp, vatot140 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_141",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_141",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_141";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot141 = betaandp, vatot141 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);


@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_142",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_142",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_142";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot142 = betaandp, vatot142 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_143",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_143",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_143";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot143 = betaandp, vatot143 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_144",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_144",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_144";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot144 = betaandp, vatot144 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_145",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_145",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_145";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot145 = betaandp, vatot145 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_146",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_146",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_146";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot146 = betaandp, vatot146 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_147",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_147",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_147";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot147 = betaandp, vatot147 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_148",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_148",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_148";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot148 = betaandp, vatot148 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_149",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_149",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_149";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot149 = betaandp, vatot149 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Repetition 150 Begins Here @

@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_150",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_150",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_150";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot150 = betaandp, vatot150 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_151",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_151",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_151";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot151 = betaandp, vatot151 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);


@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_152",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_152",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_152";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot152 = betaandp, vatot152 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_153",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_153",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_153";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot153 = betaandp, vatot153 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_154",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_154",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_154";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot154 = betaandp, vatot154 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_155",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_155",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_155";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot155 = betaandp, vatot155 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_156",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_156",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_156";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot156 = betaandp, vatot156 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_157",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_157",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_157";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot157 = betaandp, vatot157 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_158",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_158",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_158";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot158 = betaandp, vatot158 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_159",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_159",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_159";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot159 = betaandp, vatot159 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Repetition 160 Begins Here @

@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_160",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_160",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_160";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot160 = betaandp, vatot160 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_161",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_161",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_161";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot161 = betaandp, vatot161 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);


@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_162",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_162",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_162";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot162 = betaandp, vatot162 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_163",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_163",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_163";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot163 = betaandp, vatot163 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_164",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_164",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_164";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot164 = betaandp, vatot164 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_165",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_165",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_165";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot165 = betaandp, vatot165 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_166",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_166",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_166";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot166 = betaandp, vatot166 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_167",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_167",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_167";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot167 = betaandp, vatot167 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_168",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_168",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_168";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot168 = betaandp, vatot168 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_169",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_169",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_169";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot169 = betaandp, vatot169 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Repetition 170 Begins Here @

@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_170",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_170",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_170";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot170 = betaandp, vatot170 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_171",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_171",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_171";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot171 = betaandp, vatot171 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);


@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_172",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_172",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_172";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot172 = betaandp, vatot172 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_173",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_173",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_173";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot173 = betaandp, vatot173 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_174",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_174",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_174";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot174 = betaandp, vatot174 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_175",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_175",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_175";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot175 = betaandp, vatot175 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_176",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_176",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_176";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot176 = betaandp, vatot176 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_177",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_177",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_177";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot177 = betaandp, vatot177 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_178",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_178",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_178";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot178 = betaandp, vatot178 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_179",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_179",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_179";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot179 = betaandp, vatot179 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Repetition 180 Begins Here @

@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_180",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_180",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_180";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot180 = betaandp, vatot180 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_181",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_181",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_181";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot181 = betaandp, vatot181 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);


@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_182",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_182",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_182";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot182 = betaandp, vatot182 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_183",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_183",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_183";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot183 = betaandp, vatot183 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_184",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_184",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_184";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot184 = betaandp, vatot184 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_185",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_185",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_185";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot185 = betaandp, vatot185 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_186",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_186",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_186";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot186 = betaandp, vatot186 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_187",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_187",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_187";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot187 = betaandp, vatot187 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_188",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_188",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_188";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot188 = betaandp, vatot188 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_189",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_189",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_189";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot189 = betaandp, vatot189 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Repetition 190 Begins Here @

@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_190",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_190",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_190";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot190 = betaandp, vatot190 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_191",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_191",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_191";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot191 = betaandp, vatot191 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);


@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_192",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_192",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_192";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot192 = betaandp, vatot192 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_193",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_193",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_193";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot193 = betaandp, vatot193 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_194",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_194",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_194";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot194 = betaandp, vatot194 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_195",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_195",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_195";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot195 = betaandp, vatot195 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_196",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_196",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_196";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot196 = betaandp, vatot196 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_197",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_197",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_197";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot197 = betaandp, vatot197 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_198",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_198",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_198";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot198 = betaandp, vatot198 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_199",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_199",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_199";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot199 = betaandp, vatot199 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);




@ Repetition 200 Begins Here @

@ Begin another repetition @
repcount = repcount+1;

print "Repetition " repcount " of total expenditures began at " timestr(0) " on " datestr(0);

screen on;

@ Clear variables used in output @
clear b1 v1 f1 infile b2 v2 f2 met yname iname xnames;

_ptloss=1;  _ptbw=0.0; _ptmet=2;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "steep one"; _opmdmth = "newton stepbt";
{b1,v1,f1,infile,met,yname,iname,xnames}=pantob("s170_200",2,1,xvarcols,b0);


_ptmet=5;   _opstep=3;
@ Modify it to switch methods halfway through like Unix does @
_opstmth = "bfgs brent";_opmdmth = "newton stepbt";
{b2,v2,f2,infile,met,yname,iname,xnames}=pantob("s170_200",2,1,xvarcols,b1);

@ No longer use his WRTPT procedure to write the output.                    @
@ Instead, save it directly to the file. - Turn off the screen!!!!          @

screen off;

@ First, print out starting obs against the results of the two runs @
print "Repetition " repcount " - Total expenditures starting at zero";
print "Variable        Init Val         First run        Second run";
printfmt(regvars~b0~b1~b2,0~1~1~1);


print "Repetition " repcount " - Total expenditures - First run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b1~sqrt(diag(v1))~(b1./sqrt(diag(v1))),0~1~1~1);


print "Repetition " repcount " - Total expenditures - second run";
print "Variable         Coeffs.          Std err          t-val";
printfmt(regvars~b2~sqrt(diag(v2))~(b2./sqrt(diag(v2))),0~1~1~1);

print "Total expenditures ended at " timestr(0) " on " datestr(0);


@ Read in the file used to estimate the model @
file1 = "d:\\gauss\\pantob\\bootstr\\s170_200";
open infile1 = ^file1;
data1=readr(infile1,1000);
do until eof(infile1);
   data1=data1|readr(infile1,1000);
endo;
closeall infile1;

@ Now get sample proportions and their variances for the expenditure categories @
tot_cens = data1[.,2] .> 0;
app_cens = data1[.,3] .> 0;
ft_cens = data1[.,4] .> 0;
fh_cens = data1[.,5] .> 0;
fa_cens = data1[.,6] .> 0;
fre_cens = data1[.,7] .> 0;
taw_cens = data1[.,8] .> 0;
pur_cens = data1[.,9] .> 0;
snd_cens = data1[.,11] .> 0;
sn2_cens = data1[.,12] .> 0;

prop_tot = meanc(tot_cens);
prop_app = meanc(app_cens);
prop_ft = meanc(ft_cens);
prop_fh = meanc(fh_cens);
prop_fa = meanc(fa_cens);
prop_fre = meanc(fre_cens);
prop_taw = meanc(taw_cens);
prop_pur = meanc(pur_cens);
prop_snd = meanc(snd_cens);
prop_sn2 = meanc(sn2_cens);
sampsize = rows(data1);

varp_tot = (prop_tot*(1-prop_tot))/sampsize;
varp_app = (prop_app*(1-prop_app))/sampsize;
varp_ft  = (prop_ft *(1-prop_ft ))/sampsize;
varp_fh  = (prop_fh *(1-prop_fh ))/sampsize;
varp_fa  = (prop_fa *(1-prop_fa ))/sampsize;
varp_fre = (prop_fre*(1-prop_fre))/sampsize;
varp_taw = (prop_taw*(1-prop_taw))/sampsize;
varp_pur = (prop_pur*(1-prop_pur))/sampsize;
varp_snd = (prop_snd*(1-prop_snd))/sampsize;
varp_sn2 = (prop_sn2*(1-prop_sn2))/sampsize;


@ Save the beta and the Var-cov matrices for hypothesis testing @
betaandp = b2|prop_tot;
vcvwithp = (v2~zeros(rows(b2),1))|(zeros(1,rows(b2))~varp_tot);

save path=d:\gauss\pantob\matrices\ssmatrix\boot70;

@ The letter "a" in the second character of the matrix name @
@ refers to analysis for those with 70% of income from SS and using weekly indicators @
save batot200 = betaandp, vatot200 = vcvwithp;

clear data1 b1 b2 v1 v2 betaandp vcvwithp
      tot_cens app_cens ft_cens fh_cens fa_cens fre_cens taw_cens pur_cens snd_cens sn2_cens
      prop_tot prop_app prop_ft prop_fh prop_fa prop_fre prop_taw prop_pur prop_snd prop_sn2
      varp_tot varp_app varp_ft varp_fh varp_fa varp_fre varp_taw varp_pur varp_snd varp_sn2
      sampsize
      ;

print "Repetition " repcount " of total expenditures ended at " timestr(0) " on " datestr(0);



@ End of the program @
@ Jump out of Gauss @
system;

@ End the program @
end;
